ChainSyncStatus

Trait ChainSyncStatus 

pub trait ChainSyncStatus {
    // Required method
    fn is_close_to_tip(&self) -> bool;
}
An interface for checking if the synchronization is likely close to the network chain tip.

Required Methods

fn is_close_to_tip(&self) -> bool

Check if the synchronization is likely close to the network chain tip.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors