pub trait ChainSyncStatus {
// Required method
fn is_close_to_tip(&self) -> bool;
}Expand description
An interface for checking if the synchronization is likely close to the network chain tip.
Required Methods
Sourcefn is_close_to_tip(&self) -> bool
fn is_close_to_tip(&self) -> bool
Check if the synchronization is likely close to the network chain tip.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".